==> account_kit-3.0.5.tar.gz: lib/ui/containers/appsTestContainer.dart <==
import 'package:account_kit/entities/app/app.dart';
import 'package:account_kit/redux/accountKitState.dart';
import 'package:account_kit/redux/app/appActions.dart';
import 'package:built_collection/built_collection.dart';
import 'package:flutter/material.dart';
import 'package:flutter_redux/flutter_redux.dart';
import 'package:puma_network/widget/apiButton.dart';
import 'package:redux/redux.dart';

class AppsTestContainer<T extends VirtualAccountState> extends StatefulWidget {
  final void Function(String, String)? onSubmit;

  AppsTestContainer({this.onSubmit});

  @override
  _AppsTestContainer createState() => _AppsTestContainer<T>();
}

class _AppsTestContainer<T extends VirtualAccountState>
    extends State<AppsTestContainer> {
  @override
  Widget build(BuildContext context) {
    return StoreConnector<T, _ViewModel>(
        converter: (Store<T> store) => _ViewModel.create(store),
        builder: (BuildContext context, _ViewModel viewModel) =>
            _createBody(context, viewModel));
  }

  Widget _createBody(BuildContext context, _ViewModel vm) {
    return Padding(
      padding: const EdgeInsets.all(16.0),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          (Text(
            "This is a test page for the resource App",
            style: Theme.of(context).textTheme.headline6,
          )),
          Divider(),
          Row(
            children: [
              ApiButton(
                apiCall: vm.getAllApps,
                label: "GET /apps",
                color: Theme.of(context).accentColor,
              ),
              Padding(
                padding: const EdgeInsets.only(left: 8.0),
                child: Text("Fetched: ${vm.apps?.length ?? 0}"),
              )
            ],
          ),
          Row(
            children: [
              ApiButton(
                apiCall: () => vm.getAppByID(1),
                label: "GET /apps/1",
                color: Theme.of(context).accentColor,
              ),
            ],
          ),
          Row(
            children: [
              ApiButton(
                apiCall: () => vm.updateApp(1, {}),
                label: "PUT /apps/1",
                color: Theme.of(context).accentColor,
              ),
            ],
          ),
          Row(
            children: [
              ApiButton(
                apiCall: () => vm.createApp({
                  "name": "Scotus",
                  "color": "#000000",
                  "url": "denied",
                }),
                label: "POST /apps",
                color: Theme.of(context).accentColor,
              ),
            ],
          ),
          Row(
            children: [
              ApiButton(
                apiCall: () => vm.deleteApp(1),
                label: "DELETE /apps/1",
                color: Theme.of(context).accentColor,
              ),
            ],
          )
        ],
      ),
    );
  }
}

class _ViewModel {
  final Function getAllApps;
  final Function getAppByID;
  final Function updateApp;
  final Function createApp;
  final Function deleteApp;
  BuiltList<App>? apps;

  _ViewModel(
    this.getAllApps,
    this.getAppByID,
    this.updateApp,
    this.createApp,
    this.deleteApp,
    this.apps,
  );

  factory _ViewModel.create(Store<VirtualAccountState> store) {
    return _ViewModel(
      () => GetAppsAction(),
      (appID) => GetAppByIDAction(appID),
      (appID, body) => UpdateAppAction(appID, body),
      (body) => CreateAppAction(body),
      (appID) => DeleteAppAction(appID),
      store.state.accountKitState.appState.apps,
    );
  }
}

==> account_kit-3.0.8.tar.gz: lib/ui/containers/appsTestContainer.dart <==
import 'package:account_kit/entities/app/app.dart';
import 'package:account_kit/redux/accountKitState.dart';
import 'package:account_kit/redux/app/appActions.dart';
import 'package:built_collection/built_collection.dart';
import 'package:flutter/material.dart';
import 'package:flutter_redux/flutter_redux.dart';
import 'package:puma_network/widget/apiButton.dart';
import 'package:redux/redux.dart';

class AppsTestContainer<T extends VirtualAccountState> extends StatefulWidget {
  final void Function(String, String)? onSubmit;

  AppsTestContainer({this.onSubmit});

  @override
  _AppsTestContainer createState() => _AppsTestContainer<T>();
}

class _AppsTestContainer<T extends VirtualAccountState>
    extends State<AppsTestContainer> {
  @override
  Widget build(BuildContext context) {
    return StoreConnector<T, _ViewModel>(
        converter: (Store<T> store) => _ViewModel.create(store),
        builder: (BuildContext context, _ViewModel viewModel) =>
            _createBody(context, viewModel));
  }

  Widget _createBody(BuildContext context, _ViewModel vm) {
    return Padding(
      padding: const EdgeInsets.all(16.0),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          (Text(
            "This is a test page for the resource App",
            style: Theme.of(context).textTheme.headline6,
          )),
          Divider(),
          Row(
            children: [
              ApiButton(
                apiCall: vm.getAllApps,
                label: "GET /apps",
                color: Theme.of(context).colorScheme.secondary,
              ),
              Padding(
                padding: const EdgeInsets.only(left: 8.0),
                child: Text("Fetched: ${vm.apps?.length ?? 0}"),
              )
            ],
          ),
          Row(
            children: [
              ApiButton(
                apiCall: () => vm.getAppByID(1),
                label: "GET /apps/1",
                color: Theme.of(context).colorScheme.secondary,
              ),
            ],
          ),
          Row(
            children: [
              ApiButton(
                apiCall: () => vm.updateApp(1, {}),
                label: "PUT /apps/1",
                color: Theme.of(context).colorScheme.secondary,
              ),
            ],
          ),
          Row(
            children: [
              ApiButton(
                apiCall: () => vm.createApp({
                  "name": "Scotus",
                  "color": "#000000",
                  "url": "denied",
                }),
                label: "POST /apps",
                color: Theme.of(context).colorScheme.secondary,
              ),
            ],
          ),
          Row(
            children: [
              ApiButton(
                apiCall: () => vm.deleteApp(1),
                label: "DELETE /apps/1",
                color: Theme.of(context).colorScheme.secondary,
              ),
            ],
          )
        ],
      ),
    );
  }
}

class _ViewModel {
  final Function getAllApps;
  final Function getAppByID;
  final Function updateApp;
  final Function createApp;
  final Function deleteApp;
  BuiltList<App>? apps;

  _ViewModel(
    this.getAllApps,
    this.getAppByID,
    this.updateApp,
    this.createApp,
    this.deleteApp,
    this.apps,
  );

  factory _ViewModel.create(Store<VirtualAccountState> store) {
    return _ViewModel(
      () => GetAppsAction(),
      (appID) => GetAppByIDAction(appID),
      (appID, body) => UpdateAppAction(appID, body),
      (body) => CreateAppAction(body),
      (appID) => DeleteAppAction(appID),
      store.state.accountKitState.appState.apps,
    );
  }
}
